@@ -17,8 +17,6 @@ if TYPE_CHECKING:
 INNER = 1
 OUTER = 2
 
-_EMPTY_SEGMENT = Segment("", Style())
-
 BORDER_CHARS: dict[
     EdgeType, tuple[tuple[str, str, str], tuple[str, str, str], tuple[str, str, str]]
 ] = {
@@ -84,6 +82,11 @@ BORDER_CHARS: dict[
         ("▌", " ", "▐"),
         ("▙", "▄", "▟"),
     ),
+    "thick": (
+        ("█", "▀", "█"),
+        ("█", " ", "█"),
+        ("█", "▄", "█"),
+    ),
     "hkey": (
         ("▔", "▔", "▔"),
         (" ", " ", " "),
@@ -172,6 +175,11 @@ BORDER_LOCATIONS: dict[
         (0, 0, 0),
         (0, 0, 0),
     ),
+    "thick": (
+        (0, 0, 0),
+        (0, 0, 0),
+        (0, 0, 0),
+    ),
     "hkey": (
         (0, 0, 0),
         (0, 0, 0),
