@@ -8,7 +8,7 @@ of subsequent keys.
 Note that stdlib's @lru_cache is implemented in C and faster! It's best to use
 @lru_cache where you are caching things that are fairly quick and called many times.
 Use LRUCache where you want increased flexibility and you are caching slow operations
-where the overhead of the cache is a small fraction of the total processing time.  
+where the overhead of the cache is a small fraction of the total processing time.
 
 """
 
@@ -80,7 +80,7 @@ class LRUCache(Generic[CacheKey, CacheValue]):
         """Grow the maximum size to at least `maxsize` elements.
 
         Args:
-            maxsize (int): New maximum size.
+            maxsize: New maximum size.
         """
         self.maxsize = max(self.maxsize, maxsize)
 
@@ -99,8 +99,8 @@ class LRUCache(Generic[CacheKey, CacheValue]):
         """Set a value.
 
         Args:
-            key (CacheKey): Key.
-            value (CacheValue): Value.
+            key: Key.
+            value: Value.
         """
         link = self._cache.get(key)
         if link is None:
@@ -141,11 +141,11 @@ class LRUCache(Generic[CacheKey, CacheValue]):
         """Get a value from the cache, or return a default if the key is not present.
 
         Args:
-            key (CacheKey): Key
-            default (Optional[DefaultValue], optional): Default to return if key is not present. Defaults to None.
+            key: Key
+            default: Default to return if key is not present. Defaults to None.
 
         Returns:
-            Union[CacheValue, Optional[DefaultValue]]: Either the value or a default.
+            Either the value or a default.
         """
         link = self._cache.get(key)
         if link is None:
@@ -190,7 +190,7 @@ class FIFOCache(Generic[CacheKey, CacheValue]):
     do many lookups.
 
     Args:
-        maxsize (int): Maximum size of the cache.
+        maxsize: Maximum size of the cache.
     """
 
     __slots__ = [
@@ -230,8 +230,8 @@ class FIFOCache(Generic[CacheKey, CacheValue]):
         """Set a value.
 
         Args:
-            key (CacheKey): Key.
-            value (CacheValue): Value.
+            key: Key.
+            value: Value.
         """
         if key not in self._cache and len(self._cache) >= self._maxsize:
             for first_key in self._cache:
@@ -255,11 +255,11 @@ class FIFOCache(Generic[CacheKey, CacheValue]):
         """Get a value from the cache, or return a default if the key is not present.
 
         Args:
-            key (CacheKey): Key
-            default (Optional[DefaultValue], optional): Default to return if key is not present. Defaults to None.
+            key: Key
+            default: Default to return if key is not present. Defaults to None.
 
         Returns:
-            Union[CacheValue, Optional[DefaultValue]]: Either the value or a default.
+            Either the value or a default.
         """
         try:
             result = self._cache[key]
